@@ -12,4 +12,6 @@ def get_secret(name: str) -> Optional[str]:
     if name not in registered_secrets:
         raise AssertionError(f"secret {name} is not registered")
 
+    if name not in environ:
+        raise AssertionError(f"secret {name} is not set")
     return environ[name]
\ No newline at end of file
